# $Id: virtuecommerce.sql,v 1.4 2009/02/04 19:03:25 Farhad zare Exp $
#
# Virtu, Open Source E-Commerce
# http://www.e-virtu.com/
# http://www.oscommerce.com/
#
# Copyright (c) 2007-2009 Virtu E-Commerce
#
# Released under the GNU General Public License
#
# NOTE: * Please make any modifications to this file by hand!
#       * DO NOT use a mysqldump created file for new changes!
#       * Please take note of the table structure, and use this
#         structure as a standard for future modifications!
#       * Any tables you add here should be added in admin/backup.php
#         and in catalog/install/includes/functions/database.php
#       * To see the 'diff'erence between MySQL databases, use
#         the mysqldiff perl script located in the extras
#         directory of the 'catalog' module.
#       * Comments should be like these, full line comments.
#         (don't use inline comments)

DROP TABLE IF EXISTS address_book;
CREATE TABLE address_book (
   address_book_id int NOT NULL auto_increment,
   customers_id int NOT NULL,
   entry_gender char(1) NOT NULL,
   entry_company varchar(128),
   entry_firstname varchar(128) NOT NULL,
   entry_lastname varchar(128) NOT NULL,
   entry_street_address varchar(255) NOT NULL,
   entry_suburb varchar(128),
   entry_postcode varchar(11) NOT NULL,
   entry_city varchar(64) NOT NULL,
   entry_state varchar(64),
   entry_country_id int DEFAULT '0' NOT NULL,
   entry_zone_id int DEFAULT '0' NOT NULL,
   PRIMARY KEY (address_book_id),
   KEY idx_address_book_customers_id (customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS address_format;
CREATE TABLE address_format (
  address_format_id int NOT NULL auto_increment,
  address_format varchar(255) NOT NULL,
  address_summary varchar(48) NOT NULL,
  PRIMARY KEY (address_format_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS admin;
CREATE TABLE admin (
  admin_id int NOT NULL auto_increment,
  admin_groups_id int DEFAULT NULL,
  admin_firstname varchar(128) NOT NULL DEFAULT '',
  admin_lastname varchar(128) DEFAULT NULL,
  admin_email_address varchar(255) NOT NULL DEFAULT '',
  admin_password varchar(40) NOT NULL DEFAULT '',
  admin_created datetime DEFAULT NULL,
  admin_modified datetime NOT NULL DEFAULT '0000-00-00 00:00:00',
  admin_logdate datetime DEFAULT NULL,
  admin_lognum int NOT NULL DEFAULT '0',
  PRIMARY KEY  (admin_id),
  UNIQUE KEY admin_email_address (admin_email_address)  
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS admin_files;
CREATE TABLE admin_files (
  admin_files_id int NOT NULL auto_increment,
  admin_files_name varchar(64) NOT NULL DEFAULT '',
  admin_files_is_boxes tinyint(5) NOT NULL DEFAULT '0',
  admin_files_to_boxes int NOT NULL DEFAULT '0',
  admin_groups_id set('1','2') NOT NULL DEFAULT '1',
  PRIMARY KEY  (admin_files_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS admin_groups;
CREATE TABLE admin_groups (
  admin_groups_id int NOT NULL auto_increment,
  admin_groups_name varchar(64) DEFAULT NULL,
  PRIMARY KEY  (admin_groups_id),
  UNIQUE KEY admin_groups_name (admin_groups_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS banners;
CREATE TABLE banners (
  banners_id int NOT NULL auto_increment,
  banners_title varchar(128) NOT NULL,
  banners_url varchar(255) NOT NULL,
  banners_image varchar(64) NOT NULL,
  banners_group varchar(10) NOT NULL,
  banners_html_text text,
  expires_impressions int(7) DEFAULT '0',
  expires_date datetime DEFAULT NULL,
  date_scheduled datetime DEFAULT NULL,
  date_added datetime NOT NULL,
  date_status_change datetime DEFAULT NULL,
  status int(1) DEFAULT '1' NOT NULL,
  PRIMARY KEY  (banners_id),
  KEY idx_banners_group (banners_group)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS banners_history;
CREATE TABLE banners_history (
  banners_history_id int NOT NULL auto_increment,
  banners_id int NOT NULL,
  banners_shown int(5) NOT NULL DEFAULT '0',
  banners_clicked int(5) NOT NULL DEFAULT '0',
  banners_history_date datetime NOT NULL,
  PRIMARY KEY  (banners_history_id),
  KEY idx_banners_history_banners_id (banners_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS categories;
CREATE TABLE categories (
   categories_id int NOT NULL auto_increment,
   categories_image varchar(64),
   parent_id int DEFAULT '0' NOT NULL,
   sort_order int(3),
   date_added datetime,
   last_modified datetime,
   PRIMARY KEY (categories_id),
   KEY idx_categories_parent_id (parent_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS categories_description;
CREATE TABLE categories_description (
   categories_id int DEFAULT '0' NOT NULL,
   language_id int DEFAULT '1' NOT NULL,
   categories_name varchar(128) NOT NULL,
   PRIMARY KEY (categories_id, language_id),
   KEY idx_categories_name (categories_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS configuration;
CREATE TABLE configuration (
  configuration_id int NOT NULL auto_increment,
  configuration_title varchar(255) NOT NULL,
  configuration_key varchar(255) NOT NULL,
  configuration_value varchar(255) NOT NULL,
  configuration_description varchar(255) NOT NULL,
  configuration_group_id int NOT NULL,
  sort_order int(5) NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  use_function varchar(255) NULL,
  set_function varchar(255) NULL,
  PRIMARY KEY (configuration_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS configuration_group;
CREATE TABLE configuration_group (
  configuration_group_id int NOT NULL auto_increment,
  configuration_group_title varchar(64) NOT NULL,
  configuration_group_description varchar(255) NOT NULL,
  sort_order int(5) NULL,
  visible int(1) DEFAULT '1' NULL,
  PRIMARY KEY (configuration_group_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS counter;
CREATE TABLE counter (
  startdate char(8),
  counter int(12)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS counter_history;
CREATE TABLE counter_history (
  month char(8),
  counter int(12)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS countries;
CREATE TABLE countries (
  countries_id int NOT NULL auto_increment,
  countries_name varchar(64) NOT NULL,
  countries_iso_code_2 char(2) NOT NULL,
  countries_iso_code_3 char(3) NOT NULL,
  address_format_id int NOT NULL,
  PRIMARY KEY (countries_id),
  KEY IDX_COUNTRIES_NAME (countries_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS currencies;
CREATE TABLE currencies (
  currencies_id int NOT NULL auto_increment,
  title varchar(32) NOT NULL,
  code char(3) NOT NULL,
  symbol_left varchar(12),
  symbol_right varchar(12),
  decimal_point char(1),
  thousands_point char(1),
  decimal_places char(1),
  value float(13,8),
  last_updated datetime NULL,
  PRIMARY KEY (currencies_id),
  KEY idx_currencies_code (code)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS customers;
CREATE TABLE customers (
   customers_id int NOT NULL auto_increment,
   customers_gender char(1) NOT NULL,
   customers_firstname varchar(128) NOT NULL,
   customers_lastname varchar(128) NOT NULL,
   customers_dob datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
   customers_email_address varchar(96) NOT NULL,
   customers_default_address_id int,
   customers_telephone varchar(32) NOT NULL,
   customers_fax varchar(32),
   customers_password varchar(40) NOT NULL,
   customers_newsletter char(1),
   PRIMARY KEY (customers_id),
   KEY idx_customers_email_address (customers_email_address)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS customers_basket;
CREATE TABLE customers_basket (
  customers_basket_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  customers_basket_quantity int(2) NOT NULL,
  final_price decimal(15,4),
  customers_basket_date_added char(8),
  PRIMARY KEY (customers_basket_id),
  KEY idx_customers_basket_customers_id (customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS customers_basket_attributes;
CREATE TABLE customers_basket_attributes (
  customers_basket_attributes_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  products_options_id int NOT NULL,
  products_options_value_id int NOT NULL,
  PRIMARY KEY (customers_basket_attributes_id),
  KEY idx_customers_basket_att_customers_id (customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS customers_info;
CREATE TABLE customers_info (
  customers_info_id int NOT NULL,
  customers_info_date_of_last_logon datetime,
  customers_info_number_of_logons int(5),
  customers_info_date_account_created datetime,
  customers_info_date_account_last_modified datetime,
  global_product_notifications int(1) DEFAULT '0',
  PRIMARY KEY (customers_info_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS languages;
CREATE TABLE languages (
  languages_id int NOT NULL auto_increment,
  name varchar(32)  NOT NULL,
  code char(2) NOT NULL,
  image varchar(64),
  directory varchar(32),
  sort_order int(3),
  PRIMARY KEY (languages_id),
  KEY IDX_LANGUAGES_NAME (name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;


DROP TABLE IF EXISTS manufacturers;
CREATE TABLE manufacturers (
  manufacturers_id int NOT NULL auto_increment,
  manufacturers_name varchar(64) NOT NULL,
  manufacturers_image varchar(64),
  date_added datetime NULL,
  last_modified datetime NULL,
  PRIMARY KEY (manufacturers_id),
  KEY IDX_MANUFACTURERS_NAME (manufacturers_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS manufacturers_info;
CREATE TABLE manufacturers_info (
  manufacturers_id int NOT NULL,
  languages_id int NOT NULL,
  manufacturers_url varchar(255) NOT NULL,
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime NULL,
  PRIMARY KEY (manufacturers_id, languages_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS newsletters;
CREATE TABLE newsletters (
  newsletters_id int NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  content text NOT NULL,
  module varchar(255) NOT NULL,
  date_added datetime NOT NULL,
  date_sent datetime,
  status int(1),
  locked int(1) DEFAULT '0',
  PRIMARY KEY (newsletters_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders;
CREATE TABLE orders (
  orders_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  customers_name varchar(128) NOT NULL,
  customers_company varchar(128),
  customers_street_address varchar(255) NOT NULL,
  customers_suburb varchar(128),
  customers_city varchar(64) NOT NULL,
  customers_postcode varchar(11) NOT NULL,
  customers_state varchar(64),
  customers_country varchar(64) NOT NULL,
  customers_telephone varchar(32) NOT NULL,
  customers_email_address varchar(96) NOT NULL,
  customers_address_format_id int(5) NOT NULL,
  delivery_name varchar(128) NOT NULL,
  delivery_company varchar(128),
  delivery_street_address varchar(255) NOT NULL,
  delivery_suburb varchar(128),
  delivery_city varchar(64) NOT NULL,
  delivery_postcode varchar(11) NOT NULL,
  delivery_state varchar(64),
  delivery_country varchar(64) NOT NULL,
  delivery_address_format_id int(5) NOT NULL,
  billing_name varchar(128) NOT NULL,
  billing_company varchar(128),
  billing_street_address varchar(255) NOT NULL,
  billing_suburb varchar(128),
  billing_city varchar(64) NOT NULL,
  billing_postcode varchar(11) NOT NULL,
  billing_state varchar(64),
  billing_country varchar(64) NOT NULL,
  billing_address_format_id int(5) NOT NULL,
  payment_method varchar(255) NOT NULL,
  cc_type varchar(20),
  cc_owner varchar(64),
  cc_number varchar(32),
  cc_expires varchar(4),
  last_modified datetime,
  date_purchased datetime,
  orders_status int(5) NOT NULL,
  orders_date_finished datetime,
  currency char(3),
  currency_value decimal(14,6),
  PRIMARY KEY (orders_id),
  KEY idx_orders_customers_id (customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_products;
CREATE TABLE orders_products (
  orders_products_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  products_id int NOT NULL,
  products_model varchar(20),
  products_name varchar(128) NOT NULL,
  products_price decimal(15,4) NOT NULL,
  final_price decimal(15,4) NOT NULL,
  products_tax decimal(7,4) NOT NULL,
  products_quantity int(2) NOT NULL,
  PRIMARY KEY (orders_products_id),
  KEY idx_orders_products_orders_id (orders_id),
  KEY idx_orders_products_products_id (products_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_status;
CREATE TABLE orders_status (
   orders_status_id int DEFAULT '0' NOT NULL,
   language_id int DEFAULT '1' NOT NULL,
   orders_status_name varchar(32) NOT NULL,
   public_flag int DEFAULT '1',
   downloads_flag int DEFAULT '0',
   PRIMARY KEY (orders_status_id, language_id),
   KEY idx_orders_status_name (orders_status_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_status_history;
CREATE TABLE orders_status_history (
   orders_status_history_id int NOT NULL auto_increment,
   orders_id int NOT NULL,
   orders_status_id int(5) NOT NULL,
   date_added datetime NOT NULL,
   customer_notified int(1) DEFAULT '0',
   comments text,
   PRIMARY KEY (orders_status_history_id),
   KEY idx_orders_status_history_orders_id (orders_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_products_attributes;
CREATE TABLE orders_products_attributes (
  orders_products_attributes_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  orders_products_id int NOT NULL,
  products_options varchar(32) NOT NULL,
  products_options_values varchar(32) NOT NULL,
  options_values_price decimal(15,4) NOT NULL,
  price_prefix char(1) NOT NULL,
  PRIMARY KEY (orders_products_attributes_id),
  KEY idx_orders_products_att_orders_id (orders_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_products_download;
CREATE TABLE orders_products_download (
  orders_products_download_id int NOT NULL auto_increment,
  orders_id int NOT NULL default '0',
  orders_products_id int NOT NULL default '0',
  orders_products_filename varchar(255) NOT NULL default '',
  download_maxdays int(2) NOT NULL default '0',
  download_count int(2) NOT NULL default '0',
  PRIMARY KEY  (orders_products_download_id),
  KEY idx_orders_products_download_orders_id (orders_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS orders_total;
CREATE TABLE orders_total (
  orders_total_id int unsigned NOT NULL auto_increment,
  orders_id int NOT NULL,
  title varchar(255) NOT NULL,
  text varchar(255) NOT NULL,
  value decimal(15,4) NOT NULL,
  class varchar(32) NOT NULL,
  sort_order int NOT NULL,
  PRIMARY KEY (orders_total_id),
  KEY idx_orders_total_orders_id (orders_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products;
CREATE TABLE products (
  products_id int NOT NULL auto_increment,
  products_quantity int(4) NOT NULL,
  products_model varchar(20),
  products_image varchar(64),
  products_price decimal(15,4) NOT NULL,
  products_date_added datetime NOT NULL,
  products_last_modified datetime,
  products_date_available datetime,
  products_weight decimal(7,2) NOT NULL,
  products_status tinyint(1) NOT NULL,
  products_tax_class_id int NOT NULL,
  manufacturers_id int NULL,
  products_ordered int NOT NULL default '0',
  PRIMARY KEY (products_id),
  KEY idx_products_model (products_model),
  KEY idx_products_date_added (products_date_added)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_attributes;
CREATE TABLE products_attributes (
  products_attributes_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  options_id int NOT NULL,
  options_values_id int NOT NULL,
  options_values_price decimal(15,4) NOT NULL,
  price_prefix char(1) NOT NULL,
  PRIMARY KEY (products_attributes_id),
  KEY idx_products_attributes_products_id (products_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_attributes_download;
CREATE TABLE products_attributes_download (
  products_attributes_id int NOT NULL,
  products_attributes_filename varchar(255) NOT NULL default '',
  products_attributes_maxdays int(2) default '0',
  products_attributes_maxcount int(2) default '0',
  PRIMARY KEY  (products_attributes_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_description;
CREATE TABLE products_description (
  products_id int NOT NULL auto_increment,
  language_id int NOT NULL default '1',
  products_name varchar(128) NOT NULL default '',
  products_description text,
  products_url varchar(255) default NULL,
  products_viewed int(5) default '0',
  PRIMARY KEY  (products_id,language_id),
  KEY products_name (products_name)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_notifications;
CREATE TABLE products_notifications (
  products_id int NOT NULL,
  customers_id int NOT NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (products_id, customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_options;
CREATE TABLE products_options (
  products_options_id int NOT NULL default '0',
  language_id int NOT NULL default '1',
  products_options_name varchar(32) NOT NULL default '',
  PRIMARY KEY  (products_options_id,language_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_options_values;
CREATE TABLE products_options_values (
  products_options_values_id int NOT NULL default '0',
  language_id int NOT NULL default '1',
  products_options_values_name varchar(64) NOT NULL default '',
  PRIMARY KEY  (products_options_values_id,language_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_options_values_to_products_options;
CREATE TABLE products_options_values_to_products_options (
  products_options_values_to_products_options_id int NOT NULL auto_increment,
  products_options_id int NOT NULL,
  products_options_values_id int NOT NULL,
  PRIMARY KEY (products_options_values_to_products_options_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS products_to_categories;
CREATE TABLE products_to_categories (
  products_id int NOT NULL,
  categories_id int NOT NULL,
  PRIMARY KEY (products_id,categories_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS reviews;
CREATE TABLE reviews (
  reviews_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  customers_id int,
  customers_name varchar(64) NOT NULL,
  reviews_rating int(1),
  date_added datetime,
  last_modified datetime,
  reviews_read int(5) NOT NULL default '0',
  PRIMARY KEY (reviews_id),
  KEY idx_reviews_products_id (products_id),
  KEY idx_reviews_customers_id (customers_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS reviews_description;
CREATE TABLE reviews_description (
  reviews_id int NOT NULL,
  languages_id int NOT NULL,
  reviews_text text NOT NULL,
  PRIMARY KEY (reviews_id, languages_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS sb24_ereceipt;
CREATE TABLE sb24_ereceipt (
  id int NOT NULL auto_increment,
  orderid int NOT NULL,
  amount decimal(15,4) NOT NULL,
  refer_number varchar(20) NOT NULL,
  verify varchar(10) default NULL,
  treturn tinyint(1) NOT NULL default '0',
  used tinyint(1) NOT NULL default '0',
  PRIMARY KEY (id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS sb24_reservation;
CREATE TABLE sb24_reservation (
  id int NOT NULL auto_increment,
  orderid int NOT NULL,
  amount decimal(15,4) NOT NULL,
  res_number varchar(32) NOT NULL,
  PRIMARY KEY  (`id`)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS sb24_returnlog;
CREATE TABLE sb24_returnlog (
  id int NOT NULL auto_increment,
  erid int NOT NULL,
  ret_amount decimal(15,4) NOT NULL,
  error int(7) NOT NULL default '0',
  PRIMARY KEY  (`id`)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS sessions;
CREATE TABLE sessions (
  sesskey varchar(32) NOT NULL,
  expiry int(11) unsigned NOT NULL,
  value text NOT NULL,
  PRIMARY KEY (sesskey)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS specials;
CREATE TABLE specials (
  specials_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  specials_new_products_price decimal(15,4) NOT NULL,
  specials_date_added datetime,
  specials_last_modified datetime,
  expires_date datetime,
  date_status_change datetime,
  status int(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (specials_id),
  KEY idx_specials_products_id (products_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS tax_class;
CREATE TABLE tax_class (
  tax_class_id int NOT NULL auto_increment,
  tax_class_title varchar(32) NOT NULL,
  tax_class_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_class_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS tax_rates;
CREATE TABLE tax_rates (
  tax_rates_id int NOT NULL auto_increment,
  tax_zone_id int NOT NULL,
  tax_class_id int NOT NULL,
  tax_priority int(5) DEFAULT 1,
  tax_rate decimal(7,4) NOT NULL,
  tax_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_rates_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS geo_zones;
CREATE TABLE geo_zones (
  geo_zone_id int NOT NULL auto_increment,
  geo_zone_name varchar(32) NOT NULL,
  geo_zone_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (geo_zone_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS whos_online;
CREATE TABLE whos_online (
  customer_id int,
  full_name varchar(64) NOT NULL,
  session_id varchar(128) NOT NULL,
  ip_address varchar(15) NOT NULL,
  time_entry varchar(14) NOT NULL,
  time_last_click varchar(14) NOT NULL,
  last_page_url text NOT NULL
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS zones;
CREATE TABLE zones (
  zone_id int NOT NULL auto_increment,
  zone_country_id int NOT NULL,
  zone_code varchar(32) NOT NULL,
  zone_name varchar(40) NOT NULL,
  PRIMARY KEY (zone_id),
  KEY idx_zones_country_id (zone_country_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;

DROP TABLE IF EXISTS zones_to_geo_zones;
CREATE TABLE zones_to_geo_zones (
   association_id int NOT NULL auto_increment,
   zone_country_id int NOT NULL,
   zone_id int NULL,
   geo_zone_id int NULL,
   last_modified datetime NULL,
   date_added datetime NOT NULL,
   PRIMARY KEY (association_id),
   KEY idx_zones_to_geo_zones_country_id (zone_country_id)
) DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;


# data

INSERT INTO address_book VALUES ( "1", "1", "m", "ACME Inc.", "John", "Doe", "1 Way Street", "", "12345", "NeverNever", "", "223", "12");

# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany
INSERT INTO address_format VALUES (1, "$firstname $lastname$cr$streets$cr$city, $postcode$cr$statecomma$country", "$city / $country");
INSERT INTO address_format VALUES (2, "$firstname $lastname$cr$streets$cr$city, $state    $postcode$cr$country", "$city, $state / $country");
INSERT INTO address_format VALUES (3, "$firstname $lastname$cr$streets$cr$city$cr$postcode - $statecomma$country", "$state / $country");
INSERT INTO address_format VALUES (4, "$firstname $lastname$cr$streets$cr$city ($postcode)$cr$country", "$postcode / $country");
INSERT INTO address_format VALUES (5, "$firstname $lastname$cr$streets$cr$postcode $city$cr$country", "$city / $country");
INSERT INTO address_format VALUES (6, "$state $city - $streets - $firstname $lastname - کدپستي: $postcode", "$state $city");


INSERT INTO admin VALUES (1, 1, 'AdminFirstname', 'AdminLastname', 'admin@localhost', '351683ea4e19efe34874b501fdbf9792:9b', now(), '0000-00-00 00:00:00', null, 0);

INSERT INTO admin_files VALUES (1, 'administrator.php', 1, 0, '1');
INSERT INTO admin_files VALUES (2, 'configuration.php', 1, 0, '1');
INSERT INTO admin_files VALUES (3, 'catalog.php', 1, 0, '1,18');
INSERT INTO admin_files VALUES (4, 'modules.php', 1, 0, '1');
INSERT INTO admin_files VALUES (5, 'customers.php', 1, 0, '1,18');
INSERT INTO admin_files VALUES (6, 'taxes.php', 1, 0, '1');
INSERT INTO admin_files VALUES (7, 'localization.php', 1, 0, '1');
INSERT INTO admin_files VALUES (8, 'reports.php', 1, 0, '1');
INSERT INTO admin_files VALUES (9, 'tools.php', 1, 0, '1,18');
INSERT INTO admin_files VALUES (10, 'admin_members.php', 0, 1, '1');
INSERT INTO admin_files VALUES (11, 'admin_files.php', 0, 1, '1');
INSERT INTO admin_files VALUES (12, 'configuration.php', 0, 2, '1');
INSERT INTO admin_files VALUES (13, 'categories.php', 0, 3, '1');
INSERT INTO admin_files VALUES (14, 'products_attributes.php', 0, 3, '1');
INSERT INTO admin_files VALUES (15, 'manufacturers.php', 0, 3, '1');
INSERT INTO admin_files VALUES (16, 'reviews.php', 0, 3, '1');
INSERT INTO admin_files VALUES (17, 'specials.php', 0, 3, '1,18');
INSERT INTO admin_files VALUES (18, 'products_expected.php', 0, 3, '1');
INSERT INTO admin_files VALUES (19, 'modules.php', 0, 4, '1');
INSERT INTO admin_files VALUES (20, 'customers.php', 0, 5, '1,18');
INSERT INTO admin_files VALUES (21, 'orders.php', 0, 5, '1');
INSERT INTO admin_files VALUES (22, 'countries.php', 0, 6, '1');
INSERT INTO admin_files VALUES (23, 'zones.php', 0, 6, '1');
INSERT INTO admin_files VALUES (24, 'geo_zones.php', 0, 6, '1');
INSERT INTO admin_files VALUES (25, 'tax_classes.php', 0, 6, '1');
INSERT INTO admin_files VALUES (26, 'tax_rates.php', 0, 6, '1');
INSERT INTO admin_files VALUES (27, 'currencies.php', 0, 7, '1');
INSERT INTO admin_files VALUES (28, 'languages.php', 0, 7, '1');
INSERT INTO admin_files VALUES (29, 'orders_status.php', 0, 7, '1');
INSERT INTO admin_files VALUES (30, 'stats_products_viewed.php', 0, 8, '1');
INSERT INTO admin_files VALUES (31, 'stats_products_purchased.php', 0, 8, '1');
INSERT INTO admin_files VALUES (32, 'stats_customers.php', 0, 8, '1');
INSERT INTO admin_files VALUES (33, 'backup.php', 0, 9, '1');
INSERT INTO admin_files VALUES (34, 'banner_manager.php', 0, 9, '1,18');
INSERT INTO admin_files VALUES (35, 'cache.php', 0, 9, '1');
INSERT INTO admin_files VALUES (36, 'define_language.php', 0, 9, '1');
INSERT INTO admin_files VALUES (37, 'file_manager.php', 0, 9, '1');
INSERT INTO admin_files VALUES (38, 'mail.php', 0, 9, '1,18');
INSERT INTO admin_files VALUES (39, 'newsletters.php', 0, 9, '1,18');
INSERT INTO admin_files VALUES (40, 'server_info.php', 0, 9, '1');
INSERT INTO admin_files VALUES (41, 'whos_online.php', 0, 9, '1,18');
INSERT INTO admin_files VALUES (42, 'banner_statistics.php', 0, 9, '1,18');

INSERT INTO admin_groups VALUES (1, 'مدیر کل');
INSERT INTO admin_groups VALUES (2, 'ارتباط با مشتری');

INSERT INTO banners VALUES (1, "بنر اصلي", "http://www.e-virtu.com", "banners/virtuecommerce.jpg", "468x50", "", NULL, NULL, NULL, now(), NULL, "1");

INSERT INTO configuration VALUES ("1", "نام فروشگاه", "STORE_NAME", "نام فروشگاه", "نام فروشگاه شما", "1", "1", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("2", "صاحب فروشگاه", "STORE_OWNER", "", "نام صاحب فروشگاه شما", "1", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("3", "آدرس پست الكترونيكی", "STORE_OWNER_EMAIL_ADDRESS", "", "آدرس پست الكترونيكی صاحب فروشگاه", "1", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("4", "ايميل از طرف", "EMAIL_FROM", "", "آدرس پست الكترونيكی كه در هنگام فرستادن نامه به مشتری استفاده خواهد شد", "1", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("5", "كشور", "STORE_COUNTRY", "101", "نام كشوری كه فروشگاه در آنجا واقع شده است<br><br><b>توجه: لطفا بروزرسانی منطقه فروشگاه را به خاطر داشته باشيد.</b>", "1", "6", NULL, now(), "tep_get_country_name", "tep_cfg_pull_down_country_list(");
INSERT INTO configuration VALUES ("6", "منطقه", "STORE_ZONE", "", "منطقه‌ای در كشور كه فروشگاه در آنجا واقع شده است", "1", "7", NULL, now(), "tep_cfg_get_zone_name", "tep_cfg_pull_down_zone_list(");
INSERT INTO configuration VALUES ("7", "روش طبقه بندی در آينده ها", "EXPECTED_PRODUCTS_SORT", "desc", "اين روشی از كه در جعبه مخصوص محصولات در آينده برای طبقه بندی محصولات استفاده می‌شود.", "1", "8", NULL, now(), NULL, "tep_cfg_select_option(array(\'asc\', \'desc\'),");
INSERT INTO configuration VALUES ("8", "نوع دسته بندی درآينده ها", "EXPECTED_PRODUCTS_FIELD", "date_expected", "دسته بندی محصولات درآينده برحسب چه عاملی انجام شود..", "1", "9", NULL, now(), NULL, "tep_cfg_select_option(array(\'products_name\', \'date_expected\'),");
INSERT INTO configuration VALUES ("9", "انتخاب خودكار واحد پولی پيش فرض", "USE_DEFAULT_LANGUAGE_CURRENCY", "true", "هنگام تغيير زبان به طور خودکار واحد پولی پيش فرض آن زبان انتخاب شود.", "1", "10", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("10", "فرستادن سفارشات به آدرس ايميل:", "SEND_EXTRA_ORDER_EMAILS_TO", "", "فرستادن سفارشات داده شده به آدرس ايميل مورد نظر, در اين قالب وارد شود:<br> Name 1 &lt;email@address1&gt;, Name 2 &lt;email@address2&gt;", "1", "11", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("11", "حالت مطمئن جستجو (فعلا در دست ساخت)", "SEARCH_ENGINE_FRIENDLY_URLS", "false", "استفاده از حالت خاص برای همه آدرسهاي اينترنتی فروشگاه به جهت اطمينان از بهترين نتيجه در موتورهای جستجو", "1", "12", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("12", "نمايش سبد بعد از اضافه كردن محصول", "DISPLAY_CART", "true", "به نمايش درآوردن سبد خريد كاربر بعد از اضافه كردن محصول به سبد(يا اينكه در همان صفحه باقی بماند)", "1", "14", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("13", "اجازه دادن به كاربران مهمان برای تو", "ALLOW_GUEST_TO_TELL_A_FRIEND", "true", "به كاربران مهمان اجازه داده شود كه از ابزار مخصوص توصيه محصولات به دوستان استفاده كنند", "1", "15", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("14", "عملگر پيش فرض جستجو", "ADVANCED_SEARCH_DEFAULT_OPERATOR", "and", "عملگرهای پيش فرض جستجو در سايت", "1", "17", NULL, now(), NULL, "tep_cfg_select_option(array(\'and\', \'or\'),");
INSERT INTO configuration VALUES ("15", "آدرس و شماره تلفن فروشگاه", "STORE_NAME_ADDRESS", "", "در اينجا بايد نام, آدرس و شماره تلفن فروشگاه خود را برای نمايش در سندهای قابل چاپ و همچنين در روی فروشگاه وارد كنيد", "1", "18", NULL, now(), NULL, "tep_cfg_textarea(");
INSERT INTO configuration VALUES ("16", "نمايش شمارشگر شاخه ها", "SHOW_COUNTS", "true", "شمارشگری كه تعداد محصولات موجود در هر شاخه را برمی‌گرداند", "1", "19", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("17", "تعداد اعشار ماليات", "TAX_DECIMAL_PLACES", "0", "تعداد اعشاری كه در هنگام محاسبه و نمايش ماليات معتبر است", "1", "20", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("18", "نمايش قيمتها با ماليات", "DISPLAY_PRICE_WITH_TAX", "false", "اگر روشن باشد قيمتها در كل فروشگاه با ماليات نشان داده می‌شود و اگر خاموش باشد مقدار ماليات در آخر هنگام خريد اضافه می‌شود", "1", "21", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("19", "نام", "ENTRY_FIRST_NAME_MIN_LENGTH", "3", "كمترين طول برای كادر نام", "2", "1", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("20", "نام خانوادگی", "ENTRY_LAST_NAME_MIN_LENGTH", "3", "كمترين طول برای كادر نام خانوادگی", "2", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("21", "تاريخ تولد", "ENTRY_DOB_MIN_LENGTH", "10", "كمترين طول كادر تاريخ تولد", "2", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("22", "آدرس ايميل", "ENTRY_EMAIL_ADDRESS_MIN_LENGTH", "8", "كمترين طول برای كادر آدرس پست الكترونيك", "2", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("23", "آدرس خيابان", "ENTRY_STREET_ADDRESS_MIN_LENGTH", "6", "كمترين طول برای كادر آدرس خيابان", "2", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("24", "شركت", "ENTRY_COMPANY_MIN_LENGTH", "3", "كمترين طول برای كادر نام شركت", "2", "6", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("25", "كدپستی", "ENTRY_POSTCODE_MIN_LENGTH", "5", "كمترين طول برای كادر كد پستی", "2", "7", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("26", "شهر", "ENTRY_CITY_MIN_LENGTH", "3", "كمترين طول كادر شهر", "2", "8", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("27", "استان", "ENTRY_STATE_MIN_LENGTH", "2", "كمترين طول كادر استان", "2", "9", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("28", "شماره تلفن", "ENTRY_TELEPHONE_MIN_LENGTH", "5", "كمترين طول برای كادر شماره تلفن", "2", "10", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("29", "كلمه عبور", "ENTRY_PASSWORD_MIN_LENGTH", "5", "كمترين طول برای كادر كلمه عبور", "2", "11", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("30", "نام صاحب كارت اعتباری", "CC_OWNER_MIN_LENGTH", "3", "كمترين طول برای كادر نام صاحب كارت اعتباری", "2", "12", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("31", "شماره كارت اعتباری", "CC_NUMBER_MIN_LENGTH", "10", "كمترين طول برای كادر شماره كارت اعتباری", "2", "13", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("32", "متن نظر", "REVIEW_TEXT_MIN_LENGTH", "50", "كمترين طول برای كادر متن نظر", "2", "14", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("33", "بهترين فروشنده ها", "MIN_DISPLAY_BESTSELLERS", "1", "كمترين تعداد برای نمايش ليست بهترين فروشنده ها", "2", "15", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("34", "همچنين برای خريداری شده ها", "MIN_DISPLAY_ALSO_PURCHASED", "1", "كمترين تعداد محصولی كه در ليست بهترين محصولات فروخته شده نشان داده می‌شوند", "2", "16", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("35", "حجم دفترچه آدرس", "MAX_ADDRESS_BOOK_ENTRIES", "5", "حداكثر تعداد آدرسی كه يك مشتری اجازه دارد تا در دفترچه آدرس خود داشته باشد", "3", "1", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("36", "نتايج جستجو", "MAX_DISPLAY_SEARCH_RESULTS", "15", "تعداد محصولی كه ليست خواهد شد", "3", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("37", "لينكهای صفحه", "MAX_DISPLAY_PAGE_LINKS", "5", "حداكثر تعداد لينكی كه در يك صفحه مورد استفاده قرار می گيرد", "3", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("38", "محصولات فوق العاده", "MAX_DISPLAY_SPECIAL_PRODUCTS", "9", "حداكثر تعداد محصولی كه در ليست محصولات فوق العاده نشان داده می‌شود", "3", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("39", "موژول محصولات جديد", "MAX_DISPLAY_NEW_PRODUCTS", "9", "حداكثر تعداد محصولی كه در اين شاخه نشان داده می‌شود", "3", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("40", "محصولات در آينده", "MAX_DISPLAY_UPCOMING_PRODUCTS", "10", "حداكثر تعداد محصولی كه به عنوان محصولات در آينده نزديك نشان داده می‌شوند", "3", "6", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("41", "ليست سازندگان", "MAX_DISPLAY_MANUFACTURERS_IN_A_LIST", "0", "استفاده شده در جعبه مخصوص سازندگان; وقتی تعداد سازندگان از اين عدد تجاور كند, يك ليست انتخاب به جای ليست پيش فرض نمايش داده مي شود", "3", "7", NULL, now(), NULL, NULL);

INSERT INTO configuration VALUES ("43", "طول نام سازندگان", "MAX_DISPLAY_MANUFACTURER_NAME_LEN", "15", "در جعبه مخصوص سازندگان كاربرد دارد; حداكثر طول مجاز برای استفاده در نام سازندگان", "3", "8", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("44", "نظرات جديد", "MAX_DISPLAY_NEW_REVIEWS", "6", "حاكثر تعدادی از نظرات جديد كه نشان داده می‌شوند", "3", "9", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("45", "انتخابگر اتفاقی نظرات", "MAX_RANDOM_SELECT_REVIEWS", "10", "چه مقدار سطر به صورت اتفاقی از نظريات انتخاب شود؟", "3", "10", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("46", "انتخابگر اتفاقی محصولات جديد", "MAX_RANDOM_SELECT_NEW", "10", "چه تعداد سطر به صورت اتفاقی از محصولات جديد برای نمايش انتخاب شود؟", "3", "11", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("47", "انتخابگر محصولات فوق العاده", "MAX_RANDOM_SELECT_SPECIALS", "10", "چه تعداد سطر به طور اتفاقی از محصولات فوق العاده برای نمايش انتخاب شود؟", "3", "12", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("48", "شاخه های ليست شده در هرسطر", "MAX_DISPLAY_CATEGORIES_PER_ROW", "3", "چه تعداد شاخه در هر سطر ليست شود؟", "3", "13", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("49", "محصولات جديد ليست شده", "MAX_DISPLAY_PRODUCTS_NEW", "10", "حداكثر تعداد محصولات جديد كه در صفحه مخصوص آن نمايش داده می‌شود.", "3", "14", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("50", "بهترين فروشنده ها", "MAX_DISPLAY_BESTSELLERS", "10", "حداثكر تعداد بهترين فروشنده ها كه نمايش داده می‌شود.", "3", "15", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("51", "همچنين خريد شده ها", "MAX_DISPLAY_ALSO_PURCHASED", "6", "حداكثر تعداد محصولی كه در صفحه بهترين مشتری خريد كننده نشان داده می‌شود.", "3", "16", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("52", "جعبه سوابق فروش مشتری", "MAX_DISPLAY_PRODUCTS_IN_ORDER_HISTORY_BOX", "6", "حداكثر تعداد محصولی كه در جعبه سوابق فروش مشتری ليست خواهد شد.", "3", "17", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("53", "سوابق سفارش", "MAX_DISPLAY_ORDER_HISTORY", "7", "حداكثر تعداد سفارشی كه در صفحه سوابق سفارش نشان داده می‌شود.", "3", "18", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("54", "تعداد یک محصول در سبد خرید", "MAX_QTY_IN_CART", "99", "حداکثر تعدادی از یک محصول که کاربر می‌تواند به سبد خرید خود اضافه کند (0 برای نامحدود)", "3", "19", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("55", "پهنای تصوير كوچك", "SMALL_IMAGE_WIDTH", "100", "تعداد پيكسل برای پهنای تصوير كوچك", "4", "1", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("56", "ارتفاع تصوير كوچك", "SMALL_IMAGE_HEIGHT", "80", "تعداد پيكسل برای ارتفاع تصوير كوچك", "4", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("57", "پهنای تصوير سرصفحه", "HEADING_IMAGE_WIDTH", "57", "تعداد پيكسل برای پهنای تصوير سرصفحه", "4", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("58", "ارتفاع تصوير سرصفحه", "HEADING_IMAGE_HEIGHT", "40", "تعداد پيكسل برای تصوير سرصفحه", "4", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("59", "پهنای تصوير زيرشاخه", "SUBCATEGORY_IMAGE_WIDTH", "100", "تعداد پيكسل برای تصوير زيرشاخه", "4", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("60", "ارتفاع تصوير زيرشاخه", "SUBCATEGORY_IMAGE_HEIGHT", "57", "تعداد پيكسل برای ارتفاع تصوير زيرشاخه", "4", "6", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("61", "محاسبه اندازه تصوير", "CONFIG_CALCULATE_IMAGE_SIZE", "true", "آيا اندازه تصوير محاسبه شود?", "4", "7", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("62", "تصوير لازم می‌باشد", "IMAGE_REQUIRED", "true", "توانا برای نمايش تصاوير منفصل. برای توسعه دهندگان مفيد است.", "4", "8", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("149", "ایجاد تصویر کوچک", "IMAGE_THUMBNAIL", "true", "ایجاد تصویر کوچک به صورت خودکار از تصاویر فروشگاه", "4", "9", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("63", "جنسيت", "ACCOUNT_GENDER", "true", "نمايش جنسيت در حساب كاربری مشتری", "5", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("64", "تاريخ تولد", "ACCOUNT_DOB", "true", "نمايش تاريخ تولد در حساب كاربری مشتری", "5", "2", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("65", "شركت", "ACCOUNT_COMPANY", "true", "نمايش شركت در حساب كاربری مشتری", "5", "3", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("66", "حومه", "ACCOUNT_SUBURB", "true", "نمايش حومه در حساب كاربری مشتری", "5", "4", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("67", "استان", "ACCOUNT_STATE", "false", "نمايش استان در حساب كاربری مشتری", "5", "5", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("68", "موژولهای نصب شده", "MODULE_PAYMENT_INSTALLED", "cod.php", "ليست از نام فايلهای موژولهای پرداخت كه به وسيله سمی كالون ; از هم جدا شده اند. اين مقدار به صورت خودكار بروزرسانی می‌شود. نيازی به ويرايش ندارد", "6", "0", NULL, now(), NULL, NULL);

INSERT INTO configuration VALUES ("69", "موژولهای نصب شده", "MODULE_SHIPPING_INSTALLED", "flat.php", "ليستي از نام فايلهای موژولهای حمل و نقل كه به وسيله سمی كالون ; از هم جدا شده اند. اين كادر به صورت خودكار بروزرسانی می‌شود. نيازی به ويرايش ندا", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES("70", "موژولهای نصب شده", "MODULE_ORDER_TOTAL_INSTALLED", "ot_subtotal.php;ot_shipping.php;ot_tax.php;ot_total.php", "اين قسمت به صورت خودكار به روزرسانی می‌شود و نيازی به تغيير دستی ندارد.", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("253", "هزينه حمل و نقل", "MODULE_SHIPPING_FLAT_COST", "5000", "هزينه حمل و نقلی كه برای همه سفارشات در روش حمل و نقل استفاده خواهد شد.", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("243", "فعاليت مخزن براي تحويل كالا", "MODULE_PAYMENT_COD_STATUS", "True", "آيا شما می خواهيد قابليت مخزن را برای موژول تحويل كالا فعال كنيد؟", "6", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("245", "مرتبه طبقه بندی برای نمايش.", "MODULE_PAYMENT_COD_SORT_ORDER", "0", "مرتبه طبقه بندی برای نمايش دادن. كمترين مقدار بالاتر نمايش داده می‌شود.", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("246", "تنظيم وضعيت طبقه بندی", "MODULE_PAYMENT_COD_ORDER_STATUS_ID", "0", "تنظيم وضعيت طبقه بندی ساخته شده با اين موژول به وسيله اين مقدار", "6", "0", NULL, now(), "tep_get_order_status_name", "tep_cfg_pull_down_order_statuses(");
INSERT INTO configuration VALUES ("256", "مرتبه طبقه بندی", "MODULE_SHIPPING_FLAT_SORT_ORDER", "0", "مرتبه طبقه بندی برای نمايش.", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("255", "منطقه حمل و نقل", "MODULE_SHIPPING_FLAT_ZONE", "0", "اگر منطقه ای انتخاب شود, اين روش حمل و نقل فقط برای آن منطقه فعال خواهد بود.", "6", "0", NULL, now(), "tep_get_zone_class_title", "tep_cfg_pull_down_zone_classes(");
INSERT INTO configuration VALUES ("84", "واحد پولی پيش فرض", "DEFAULT_CURRENCY", "IRR", "واحد پولی پيش فرض", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("85", "زبان پيش فرض", "DEFAULT_LANGUAGE", "fa", "زبان پيش فرض", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("86", "وضعيت پيش فرض در سفارشات جديد", "DEFAULT_ORDERS_STATUS_ID", "1", "وقتی كه سفارش جديدی ايجاد می‌شود, اين وضعيت برای آن سفارش داده خواهد شد.", "6", "0", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("267", "حمل و نقل رايگان در سفارشات بالای", "MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER", "300000", "فعال بودن حمل  و نقل رايگان برای سفارشات كه از مقدار تنظيم شده بالاتر هستند.", "6", "4", NULL, now(), "currencies->format", NULL);
INSERT INTO configuration VALUES ("266", "اجازه دادن به حمل و نقل رايگان", "MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING", "false", "آيا شما می‌خواهيد كه به حمل و نقل رايگان اجازه داده شود؟", "6", "3", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("265", "مرتبه طبقه بندی", "MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER", "2", "مرتبه طبقه بندی برای نمايش دادن.", "6", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("270", "مرتبه طبقه بندی", "MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER", "1", "مرتبه طبقه بندی برای نمايش دادن.", "6", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("274", "مرتبه طبقه بندی", "MODULE_ORDER_TOTAL_TAX_SORT_ORDER", "3", "مرتبه ای از طبقه بندی برای نمايش دادن.", "6", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("96", "نمايش جمع كل", "MODULE_ORDER_TOTAL_TOTAL_STATUS", "true", "آيا شما می‌خواهيد كه مقدار جمع كل سفارش نمايش داده شود؟", "6", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("97", "مرتبه طبقه بندی", "MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER", "4", "مرتبه  طبقه بندی برای نمايش دادن.", "6", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("98", "كشور مبدا", "SHIPPING_ORIGIN_COUNTRY", "101", "انتخاب كشور مبدا  برای استفاده در نقل قولهای حمل و نقل.", "7", "1", NULL, now(), "tep_get_country_name", "tep_cfg_pull_down_country_list(");
INSERT INTO configuration VALUES ("99", "كدپستی", "SHIPPING_ORIGIN_ZIP", "", "وارد كنيد كدپستی فروشگاه را برای استفاده در نقل قولهای حمل  ونقل.", "7", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("100", "حداكثر وزن بسته‌ای برای حمل شدن", "SHIPPING_MAX_WEIGHT", "10000", "حداكثر محدوديت وزن برای يك بسته. اين مقدار برای يكی عادی است.", "7", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("101", "وزن خالص بسته بندی.", "SHIPPING_BOX_WEIGHT", "100", "وزن خالص يك بسته بندی برای يك سفارش چه كوچك و چه متوسط چقدر است؟", "7", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("102", "بسته‌های بزرگتر- افزايش برحسب درصد.", "SHIPPING_BOX_PADDING", "0", "برای 10% وارد كنيد عدد10 را", "7", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("103", "نمايش تصوير محصول", "PRODUCT_LIST_IMAGE", "1", "آيا شما می خواهيد كه تصويری برای محصول نمايش داده شود؟", "8", "1", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("104", "نمايش نام سازنده محصول", "PRODUCT_LIST_MANUFACTURER", "1", "آيا شما می‌خواهيد كه نام سازنده محصول نمايش داده شود؟", "8", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("105", "نمايش مدل محصول", "PRODUCT_LIST_MODEL", "1", "آيا شما می خواهيد كه مدل محصول نمايش داده شود؟", "8", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("106", "نمايش نام محصول", "PRODUCT_LIST_NAME", "2", "آيا شما می خواهيد كه نام محصول نمايش داده شود؟", "8", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("107", "نمايش قيمت محصول", "PRODUCT_LIST_PRICE", "3", "آيا شما می خواهيد كه قيمت محصول نمايش داده شود؟", "8", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("108", "نمايش موجودی محصول", "PRODUCT_LIST_QUANTITY", "0", "آيا شما می خواهيد كه موجودی محصول نشان داده شود؟", "8", "6", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("109", "نمايش وزن محصول", "PRODUCT_LIST_WEIGHT", "0", "آيا شما می خواهيد كه وزن محصول نمايش داده شود؟", "8", "7", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("110", "نمايش ستون خريد کالا", "PRODUCT_LIST_BUY_NOW", "4", "آيا شما می خواهيد كه ستون خريد حالا نمايش داده شود؟", "8", "8", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("111", "فيلتر شاخه ها/سازندگان (1= فعال كردن)", "PRODUCT_LIST_FILTER", "1", "آيا شما می‌خواهيد كه فيلتر شاخه ها / سازندگان نمايش داده شود؟", "8", "9", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("112", "نوارهدايتی قبلی/بعدی(1=بالا, 2=پايين)", "PREV_NEXT_BAR_LOCATION", "2", "تنظيم كردن محل نمايش نوار هدايتی قبلی/بعدی(1-بالا, 2-پايين, 3-هردو)", "8", "10", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("113", "بررسی سطح موجودی", "STOCK_CHECK", "true", "بررسی كند تا ببيند اگر سطح موجودی كافی است دسترس پذير باشد", "9", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("114", "كاستن از موجودی", "STOCK_LIMITED", "true", "كم كردن از محصولات موجود در فروشگاه با سفارش دادن آنها", "9", "2", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("115", "اجازه پرداخت نهايی", "STOCK_ALLOW_CHECKOUT", "true", "اجازه دادن به مشتری برای رفتن به مرحله پرداخت نهايی حتی اگر موجودی كافی نباشد", "9", "3", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("116", "نشانه گذاری محصولات خارج از موجودی", "STOCK_MARK_PRODUCT_OUT_OF_STOCK", "***", "نمايش چيزی در صفحه برای مشتری تا به وسيله آن بتواند بفهمد كه چه محصولی به مقدار كافی در موجودی نيست", "9", "4", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("117", "سطح موجودی دوباره سفارش", "STOCK_REORDER_LEVEL", "5", "تعيين كردن مقداری كه برای سفارش دوباره لازم است", "9", "5", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("118", "زمان ايجاد صفحه فروشگاه", "STORE_PAGE_PARSE_TIME", "false", "مقدار زمانی كه صرف می شود برای ايجاد صفحه فروشگاه", "10", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("119", "مقصد واقع نگار(log)", "STORE_PAGE_PARSE_TIME_LOG", "/tmp/", "پوشه يا نام فايلی برای واقعه نگار زمان ايجاد صفحه", "10", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("120", "قالب تاريخ واقعه نگار", "STORE_PARSE_DATE_TIME_FORMAT", "%d/%m/%Y %H:%M:%S", "قالب تاريخ", "10", "3", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("121", "نمايش وقت ايجاد صفحه", "DISPLAY_PAGE_PARSE_TIME", "true", "نمايش زمان ايجاد صفحه(زمان ايجاد صفحه فروشگاه بايد فعال باشد)", "10", "4", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("122", "بازجستهای پايگاه داده فروشگاه", "STORE_DB_TRANSACTIONS", "false", "بازجستهای پايگاه داده برای واقعه نگار زمان ايجاد صفحه فروشگاه(فقط PHP4)", "10", "5", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("123", "استفاده از مخزن", "USE_CACHE", "false", "استفاده از طرح مخزن", "11", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("124", "پوشه فايلهای مخزن", "DIR_FS_CACHE", "/tmp/", "پوشه‌ای كه فايلهای مخزن در آنجا ذخيره می‌شوند.", "11", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("125", "روش انتقال پست الكترونيك", "EMAIL_TRANSPORT", "sendmail", "تعريفهايی برای سرورهای كه از يك ارتباط محلی برای sendmail يا از ارتباط SMTP به وسيله TCP/IP استفاده می كنند. سرورهای Windows و  MacOS بايد از SMTP استفاده كنند.", "12", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'sendmail\', \'smtp\'),");
INSERT INTO configuration VALUES ("126", "خط تغذيه پست الكترونيك", "EMAIL_LINEFEED", "LF", "تعريف كردن رشته كاراكترهای جداگانه كه در هدرهای mail استفاده شده اند.", "12", "2", NULL, now(), NULL, "tep_cfg_select_option(array(\'LF\', \'CRLF\'),");
INSERT INTO configuration VALUES ("127", "استفاده از MIME HTML هنگام ارسال نامه", "EMAIL_USE_HTML", "true", "ارسال نامه های شما با قالب HTML", "12", "3", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("128", "بازبيني آدرس پست الكترونيك از ميان", "ENTRY_EMAIL_ADDRESS_CHECK", "false", "بازبينی آدرس پست الكترونيك از ميان تنظيمات DNS سرور", "12", "4", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("129", "فرستادن نامه ها", "SEND_EMAILS", "true", "فرستادن نامه به خارج", "12", "5", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("130", "فعال كردن دريافت فايل", "DOWNLOAD_ENABLED", "false", "فعال كردن توابع دريافت فايل محصولات.", "13", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("131", "دريافت كردن بعد از راهنمايی", "DOWNLOAD_BY_REDIRECT", "false", "استفاده از امكان راهنمايی مجدد مرورگر برای دريافت فايل. غيرفعال كردن در سيستمهای غير Unix.", "13", "2", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("132", "به تاخير انداختن انقضا (روزها)", "DOWNLOAD_MAX_DAYS", "7", "تنظيم كردن تعدادی از روزها كه بعد از آن لينك دريافت فايل غيرقابل استفاده است. 0 به معني بدون محدوديت.", "13", "3", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("133", "حداكثر تعداد دريافت", "DOWNLOAD_MAX_COUNT", "5", "تنظيم كردن تعدادی برای حداكثر تعداد دريافت فايل. 0 به معنی بدون محدويت تعداد دريافت فايل.", "13", "4", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("134", "فعال كردن فشرده سازی GZip", "GZIP_COMPRESSION", "false", "فعال كردن فشرده سازی HTTP GZip.", "14", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("135", "سطح فشرده سازی", "GZIP_LEVEL", "5", "استفاده از سطح فشرده سازی بين اعداد0-9 (0 = حداقل, 9 = حداكثر).", "14", "2", NULL, now(), NULL, NULL);
INSERT INTO configuration VALUES ("136", "پوشه Session", "SESSION_WRITE_DIRECTORY", "/tmp", "اگر فايلهای  sessions مستقر هستند, ذخيره كردن آنها در اين پوشه.", "15", "1", NULL, now(), "", NULL);
INSERT INTO configuration VALUES ("137", "استفاده از نيروی Cookie", "SESSION_FORCE_COOKIE_USE", "False", "نيروی استفاده شده برای sessionها وقتي كه cookies فعال هستند.", "15", "2", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("138", "بررسی كد SSL Session", "SESSION_CHECK_SSL_SESSION_ID", "False", "فعال كردن كد SSL_SESSION_ID در هربار درخواست HTTPS صفحه.", "15", "3", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("139", "بررسی عامل كاربری", "SESSION_CHECK_USER_AGENT", "False", "معتبر ساختن بررسی عامل كاربری مرورگر طرف كاربر در هر درخواست صفحه.", "15", "4", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("140", "بررسی آدرس IP", "SESSION_CHECK_IP_ADDRESS", "False", "معتبر ساختن آدرس IP طرف كاربر در هر صفحه.", "15", "5", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("141", "مانع شدن از Spider Sessions", "SESSION_BLOCK_SPIDERS", "False", "مانع شدن از spiders شناخته شده در هنگام اغاز به كار session.", "15", "6", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("142", "ايجاد دوباره Session", "SESSION_RECREATE", "False", "ايجاد دوباره session برای توليد كردن كد session وقتی كه مشتری وارد حساب كاربری خود می‌شود(PHP >=4.1 نياز است).", "15", "7", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");
INSERT INTO configuration VALUES ("143", "آدرس سرور SMTP", "EMAIL_SMTP_HOST_SERVER", "smtp.mailserver.net", "ادرس سرور SMTP برای استفاده به هنگام ارسال ایمیل", "12", "10", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("144", "آدرس Helo مربوط به سرور SMTP", "EMAIL_SMTP_HELO_SERVER", "mailserver.net", "آدرس Helo مربوط به سرور SMTP برای شروع عملیات ارسال ایمیل", "12", "11", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("145", "آدرس پورت سرور SMTP", "EMAIL_SMTP_PORT_SERVER", "25", "آدرس پورت مربوط به سرور SMTP (به صورت پیش فرض 25)", "12", "12", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("146", "استفاده از کلمه عبور برروی سرور SMTP", "EMAIL_SMTP_ACTIVE_PASSWORD", "false", "برای استفاده از SMTP و فعالسازی آن کلمه عبور بکار گرفته شود.", "12", "13", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'), ");
INSERT INTO configuration VALUES ("147", "نام کاربری ایمیل برای SMTP", "EMAIL_SMTP_USERNAME", "e-mail username", "نام کاربری ایمیل که به هنگام ارسال نامه ها استفاده خواهد شد.", "12", "14", NULL, now(), NULL, "");
INSERT INTO configuration VALUES ("148", "کلمه عبور ایمیل برای SMTP", "EMAIL_SMTP_PASSWORD", "e-mail password", "کلمه عبور مربوطه برای نام کاربری SMTP که در بالا وارد شده است.", "12", "15", NULL, now(), 'tep_view_password', "tep_cfg_password_field(");
INSERT INTO configuration VALUES ("244", "مناطق پرداخت", "MODULE_PAYMENT_COD_ZONE", "0", "اگر يك منطقه انتخاب شود, فقط اين روش پرداخت برای آن منطقه فعال می شود.", "6", "2", NULL, now(), "tep_get_zone_class_title", "tep_cfg_pull_down_zone_classes(");
INSERT INTO configuration VALUES ("254", "كلاس مالياتی", "MODULE_SHIPPING_FLAT_TAX_CLASS", "0", "استفاده از كلاس مالياتی زير در قيمت حمل و نقل.", "6", "0", NULL, now(), "tep_get_tax_class_title", "tep_cfg_pull_down_tax_classes(");
INSERT INTO configuration VALUES ("268", "حمل  و نقل رايگان برای سفارشات حالت", "MODULE_ORDER_TOTAL_SHIPPING_DESTINATION", "national", "مهيا بودن حمل  و نقل رايگان برای سفارشات كه در حالت تعيين شده هستند.", "6", "5", NULL, now(), NULL, "tep_cfg_select_option(array(\'national\', \'international\', \'both\'),");
INSERT INTO configuration VALUES ("264", "نمايش حمل و نقل", "MODULE_ORDER_TOTAL_SHIPPING_STATUS", "true", "آيا شما می‌خواهيد كه برای حمل و نقل سفارشات هزينه‌ای نمايش پيدا كند؟", "6", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("269", "نمايش زيرجمع", "MODULE_ORDER_TOTAL_SUBTOTAL_STATUS", "true", "آيا شما می‌خواهيد كه هزينه به صورت زيرجمع برای سفارش نشان داده شود؟", "6", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("273", "نمايش ماليات", "MODULE_ORDER_TOTAL_TAX_STATUS", "true", "آيا شما می‌خواهيد كه برای سفارش هزينه مالياتی را نمايش دهيد؟", "6", "1", NULL, now(), NULL, "tep_cfg_select_option(array(\'true\', \'false\'),");
INSERT INTO configuration VALUES ("252", "فعال ساختن حمل و نقل هموار", "MODULE_SHIPPING_FLAT_STATUS", "True", "آيا شما می‌خواهيد نرخ ثابتی برای حمل و نقل ارائه كنيد؟", "6", "0", NULL, now(), NULL, "tep_cfg_select_option(array(\'True\', \'False\'),");

INSERT INTO configuration_group VALUES ("1", "فروشگاه من", "اطلاعات عمومی درباره فروشگاه من", "1", "1");
INSERT INTO configuration_group VALUES ("2", "مقادير حداقل", "حداقل مقادير برای توابع و اطلاعات", "2", "1");
INSERT INTO configuration_group VALUES ("3", "حداكثر مقادير", "حداكثر مقادير برای توابع و اطلاعات", "3", "1");
INSERT INTO configuration_group VALUES ("4", "تصاوير", "پارامترهای تصاوير", "4", "1");
INSERT INTO configuration_group VALUES ("5", "جزئيات مشتری", "پيكربندی حساب مشتری", "5", "1");
INSERT INTO configuration_group VALUES ("6", "اختيارات موژول", "پنهان از پيكربندی", "6", "0");
INSERT INTO configuration_group VALUES ("7", "حمل و نقل/بسته بندی", "اختيارات حمل و نقل دسترس پذير در فروشگاه", "7", "1");
INSERT INTO configuration_group VALUES ("8", "فهرست محصولات", "اختيارات پيكربندی فهرست محصولات", "8", "1");
INSERT INTO configuration_group VALUES ("9", "موجودی", "اختيارات پيكربندی موجودی", "9", "1");
INSERT INTO configuration_group VALUES ("10", "واقعه نگاری", "اختيارات پيكربندی واقعه نگاری", "10", "1");
INSERT INTO configuration_group VALUES ("11", "مخزن", "اختيارات پيكربندی مخزن", "11", "1");
INSERT INTO configuration_group VALUES ("12", "اختيارات ايميل", "تنظيمات عمومی برای انتقال ايميل و ايميهای HTML", "12", "1");
INSERT INTO configuration_group VALUES ("13", "دريافت فايل", "اختياراتی برای قابليت دريافت محصولات", "13", "1");
INSERT INTO configuration_group VALUES ("14", "فشرده سازی GZip", "اختياراتی برای فشرده سازی GZip", "14", "1");
INSERT INTO configuration_group VALUES ("15", "Sessions", "اختيارات Session", "15", "1");

INSERT INTO countries VALUES (1, "افغانستان", "AF", "AFG", "1");
INSERT INTO countries VALUES (2, "آلبانی", "AL", "ALB", "1");
INSERT INTO countries VALUES (10, "آرژانتين", "AR", "ARG", "1");
INSERT INTO countries VALUES (11, "ارمنستان", "AM", "ARM", "1");
INSERT INTO countries VALUES (13, "استراليا", "AU", "AUS", "1");
INSERT INTO countries VALUES (14, "اتريش", "AT", "AUT", "5");
INSERT INTO countries VALUES (15, "آذربايجان", "AZ", "AZE", "1");
INSERT INTO countries VALUES (17, "بحرين", "BH", "BHR", "1");
INSERT INTO countries VALUES (18, "بنگلادش", "BD", "BGD", "1");
INSERT INTO countries VALUES (20, "روسيه سفيد", "BY", "BLR", "1");
INSERT INTO countries VALUES (21, "بلژيك", "BE", "BEL", "1");
INSERT INTO countries VALUES (27, "بوسني هرزگوين", "BA", "BIH", "1");
INSERT INTO countries VALUES (30, "برزيل", "BR", "BRA", "1");
INSERT INTO countries VALUES (33, "بلغارستان", "BG", "BGR", "1");
INSERT INTO countries VALUES (37, "كامرون", "CM", "CMR", "1");
INSERT INTO countries VALUES (38, "كانادا", "CA", "CAN", "1");
INSERT INTO countries VALUES (41, "جمهوری افريقای مركزی", "CF", "CAF", "1");
INSERT INTO countries VALUES (43, "شيلی", "CL", "CHL", "1");
INSERT INTO countries VALUES (44, "چين", "CN", "CHN", "1");
INSERT INTO countries VALUES (47, "كلمبيا", "CO", "COL", "1");
INSERT INTO countries VALUES (51, "كوستاريكا", "CR", "CRI", "1");
INSERT INTO countries VALUES (53, "كرواسی", "HR", "HRV", "1");
INSERT INTO countries VALUES (54, "كوبا", "CU", "CUB", "1");
INSERT INTO countries VALUES (55, "قبرس", "CY", "CYP", "1");
INSERT INTO countries VALUES (56, "جمهوري چك", "CZ", "CZE", "1");
INSERT INTO countries VALUES (57, "دانمارك", "DK", "DNK", "1");
INSERT INTO countries VALUES (62, "اكوادور", "EC", "ECU", "1");
INSERT INTO countries VALUES (70, "جزاير فارو", "FO", "FRO", "1");
INSERT INTO countries VALUES (72, "فنلاند", "FI", "FIN", "1");
INSERT INTO countries VALUES (73, "فرانسه", "FR", "FRA", "1");
INSERT INTO countries VALUES (80, "يونان", "GE", "GEO", "1");
INSERT INTO countries VALUES (81, "آلمان", "DE", "DEU", "5");
INSERT INTO countries VALUES (84, "گرجستان", "GR", "GRC", "1");
INSERT INTO countries VALUES (96, "هنگ كنگ", "HK", "HKG", "1");
INSERT INTO countries VALUES (97, "مجارستان", "HU", "HUN", "1");
INSERT INTO countries VALUES (98, "ايسلند", "IS", "ISL", "1");
INSERT INTO countries VALUES (99, "هند", "IN", "IND", "1");
INSERT INTO countries VALUES (100, "اندونزی", "ID", "IDN", "1");
INSERT INTO countries VALUES (101, "----- ايران -----", "IR", "IRN", "6");
INSERT INTO countries VALUES (102, "عراق", "IQ", "IRQ", "1");
INSERT INTO countries VALUES (103, "ايرلند", "IE", "IRL", "1");
INSERT INTO countries VALUES (105, "ايتاليا", "IT", "ITA", "1");
INSERT INTO countries VALUES (106, "جامائيكا", "JM", "JAM", "1");
INSERT INTO countries VALUES (107, "ژاپن", "JP", "JPN", "1");
INSERT INTO countries VALUES (108, "اردن", "JO", "JOR", "1");
INSERT INTO countries VALUES (109, "قزاقستان", "KZ", "KAZ", "1");
INSERT INTO countries VALUES (112, "جمهوری مردمی دمكرات كره", "KP", "PRK", "1");
INSERT INTO countries VALUES (113, "جمهوری كره", "KR", "KOR", "1");
INSERT INTO countries VALUES (114, "كويت", "KW", "KWT", "1");
INSERT INTO countries VALUES (115, "قرقيزستان", "KG", "KGZ", "1");
INSERT INTO countries VALUES (118, "لبنان", "LB", "LBN", "1");
INSERT INTO countries VALUES (122, "ليختن اشتاين", "LI", "LIE", "1");
INSERT INTO countries VALUES (123, "لتونی", "LT", "LTU", "1");
INSERT INTO countries VALUES (124, "لوگزامبرگ", "LU", "LUX", "1");
INSERT INTO countries VALUES (126, "مقدونيه", "MK", "MKD", "1");
INSERT INTO countries VALUES (129, "مالزی", "MY", "MYS", "1");
INSERT INTO countries VALUES (130, "مولداوی", "MV", "MDV", "1");
INSERT INTO countries VALUES (131, "مالی", "ML", "MLI", "1");
INSERT INTO countries VALUES (132, "مالت", "MT", "MLT", "1");
INSERT INTO countries VALUES (138, "مكزيك", "MX", "MEX", "1");
INSERT INTO countries VALUES (140, "جمهوری مولدوا", "MD", "MDA", "1");
INSERT INTO countries VALUES (141, "موناكو", "MC", "MCO", "1");
INSERT INTO countries VALUES (144, "مراكش", "MA", "MAR", "1");
INSERT INTO countries VALUES (150, "هلند", "NL", "NLD", "1");
INSERT INTO countries VALUES (153, "نيوزلند", "NZ", "NZL", "1");
INSERT INTO countries VALUES (155, "نيجر", "NE", "NER", "1");
INSERT INTO countries VALUES (156, "نيجريه", "NG", "NGA", "1");
INSERT INTO countries VALUES (160, "نروژ", "NO", "NOR", "1");
INSERT INTO countries VALUES (161, "عمان", "OM", "OMN", "1");
INSERT INTO countries VALUES (162, "پاكستان", "PK", "PAK", "1");
INSERT INTO countries VALUES (166, "پاراگوئه", "PY", "PRY", "1");
INSERT INTO countries VALUES (167, "پرو", "PE", "PER", "1");
INSERT INTO countries VALUES (168, "فليپين", "PH", "PHL", "1");
INSERT INTO countries VALUES (170, "لهستان", "PL", "POL", "1");
INSERT INTO countries VALUES (171, "پرتغال", "PT", "PRT", "1");
INSERT INTO countries VALUES (173, "قطر", "QA", "QAT", "1");
INSERT INTO countries VALUES (175, "رومانی", "RO", "ROM", "1");
INSERT INTO countries VALUES (176, "روسيه", "RU", "RUS", "1");
INSERT INTO countries VALUES (184, "عربستان سعودی", "SA", "SAU", "1");
INSERT INTO countries VALUES (185, "سنگال", "SN", "SEN", "1");
INSERT INTO countries VALUES (188, "سنگاپور", "SG", "SGP", "4");
INSERT INTO countries VALUES (189, "اسلووكی", "SK", "SVK", "1");
INSERT INTO countries VALUES (190, "اسلوونی", "SI", "SVN", "1");
INSERT INTO countries VALUES (193, "افريقاي جنوبی", "ZA", "ZAF", "1");
INSERT INTO countries VALUES (195, "اسپانيا", "ES", "ESP", "3");
INSERT INTO countries VALUES (202, "سوئيس", "SZ", "SWZ", "1");
INSERT INTO countries VALUES (203, "سوئد", "SE", "SWE", "1");
INSERT INTO countries VALUES (206, "تايوان", "TW", "TWN", "1");
INSERT INTO countries VALUES (207, "تاجيكستان", "TJ", "TJK", "1");
INSERT INTO countries VALUES (209, "تايلند", "TH", "THA", "1");
INSERT INTO countries VALUES (214, "تونس", "TN", "TUN", "1");
INSERT INTO countries VALUES (215, "تركيه", "TR", "TUR", "1");
INSERT INTO countries VALUES (216, "تركمنستان", "TM", "TKM", "1");
INSERT INTO countries VALUES (220, "اكراين", "UA", "UKR", "1");
INSERT INTO countries VALUES (221, "امارات متحره عربی", "AE", "ARE", "1");
INSERT INTO countries VALUES (223, "ايالات متحده امريكا", "US", "USA", "2");
INSERT INTO countries VALUES (225, "اروگوئه", "UY", "URY", "1");
INSERT INTO countries VALUES (226, "ازبكستان", "UZ", "UZB", "1");
INSERT INTO countries VALUES (229, "ونوزئلا", "VE", "VEN", "1");
INSERT INTO countries VALUES (235, "يمن", "YE", "YEM", "1");
INSERT INTO countries VALUES (236, "يوگسلاوی", "YU", "YUG", "1");

INSERT INTO currencies VALUES (1, "دلار", "USD", "$", "", ".", ",", "2", "0.00009984", now());
INSERT INTO currencies VALUES (2, "یورو", "EUR", "", "EUR", ".", ",", "2", "0.00014059", now());
INSERT INTO currencies VALUES (3, "ريال", "IRR", "", "ريال", ".", ",", "0", "1.00000000", now());
INSERT INTO currencies VALUES (4, "تومان", "TMN", "", "تومان", ".", ",", "0", "0.10000000", now());

INSERT INTO customers VALUES ("1", "m", "John", "doe", "2001-01-01 00:00:00", "root@localhost", "1", "12345", "", "d95e8fa7f20a009372eb3477473fcd34:1c", "0");

INSERT INTO customers_info VALUES ("1", NULL, "0", now(), NULL, "0");

INSERT INTO languages VALUES (1,'انگلیسی','en','icon.gif','english',2);
INSERT INTO languages VALUES (4, "فارسی", "fa", "flag.gif", "farsi", 1);

INSERT INTO orders_status VALUES ('1', '4', 'منتظر رسيدگی', '1', '0');
INSERT INTO orders_status VALUES ('1', '1', 'Pending', '1', '0');
INSERT INTO orders_status VALUES ('2', '4', 'در حال آماده شدن', '1', '1');
INSERT INTO orders_status VALUES ('2', '1', 'Processing', '1', '1');
INSERT INTO orders_status VALUES ('3', '4', 'تحويل داده شده', '1', '1');
INSERT INTO orders_status VALUES ('3', '1', 'Delivered', '1', '1');

INSERT INTO tax_class VALUES (1, "ارزش افزوده", "مالیات و عوارض کالا و خدمات", now(), now());

# Iran/All
INSERT INTO tax_rates VALUES (1, 1, 1, 1, 3.0000, "مالیات ارزش افزوده+عوارض", now(), now());
INSERT INTO geo_zones VALUES (1, "ايران", "تمامی مناطق داخل ایران", now(), now());
INSERT INTO zones_to_geo_zones VALUES (1, 101, 0, 1, NULL, now());


# USA
INSERT INTO zones VALUES (1, 223, "AL", "Alabama");
INSERT INTO zones VALUES (2, 223, "AK", "Alaska");
INSERT INTO zones VALUES (3, 223, "AS", "American Samoa");
INSERT INTO zones VALUES (4, 223, "AZ", "Arizona");
INSERT INTO zones VALUES (5, 223, "AR", "Arkansas");
INSERT INTO zones VALUES (6, 223, "AF", "Armed Forces Africa");
INSERT INTO zones VALUES (7, 223, "AA", "Armed Forces Americas");
INSERT INTO zones VALUES (8, 223, "AC", "Armed Forces Canada");
INSERT INTO zones VALUES (9, 223, "AE", "Armed Forces Europe");
INSERT INTO zones VALUES (10, 223, "AM", "Armed Forces Middle East");
INSERT INTO zones VALUES (11, 223, "AP", "Armed Forces Pacific");
INSERT INTO zones VALUES (12, 223, "CA", "California");
INSERT INTO zones VALUES (13, 223, "CO", "Colorado");
INSERT INTO zones VALUES (14, 223, "CT", "Connecticut");
INSERT INTO zones VALUES (15, 223, "DE", "Delaware");
INSERT INTO zones VALUES (16, 223, "DC", "District of Columbia");
INSERT INTO zones VALUES (17, 223, "FM", "Federated States Of Micronesia");
INSERT INTO zones VALUES (18, 223, "FL", "Florida");
INSERT INTO zones VALUES (19, 223, "GA", "Georgia");
INSERT INTO zones VALUES (20, 223, "GU", "Guam");
INSERT INTO zones VALUES (21, 223, "HI", "Hawaii");
INSERT INTO zones VALUES (22, 223, "ID", "Idaho");
INSERT INTO zones VALUES (23, 223, "IL", "Illinois");
INSERT INTO zones VALUES (24, 223, "IN", "Indiana");
INSERT INTO zones VALUES (25, 223, "IA", "Iowa");
INSERT INTO zones VALUES (26, 223, "KS", "Kansas");
INSERT INTO zones VALUES (27, 223, "KY", "Kentucky");
INSERT INTO zones VALUES (28, 223, "LA", "Louisiana");
INSERT INTO zones VALUES (29, 223, "ME", "Maine");
INSERT INTO zones VALUES (30, 223, "MH", "Marshall Islands");
INSERT INTO zones VALUES (31, 223, "MD", "Maryland");
INSERT INTO zones VALUES (32, 223, "MA", "Massachusetts");
INSERT INTO zones VALUES (33, 223, "MI", "Michigan");
INSERT INTO zones VALUES (34, 223, "MN", "Minnesota");
INSERT INTO zones VALUES (35, 223, "MS", "Mississippi");
INSERT INTO zones VALUES (36, 223, "MO", "Missouri");
INSERT INTO zones VALUES (37, 223, "MT", "Montana");
INSERT INTO zones VALUES (38, 223, "NE", "Nebraska");
INSERT INTO zones VALUES (39, 223, "NV", "Nevada");
INSERT INTO zones VALUES (40, 223, "NH", "New Hampshire");
INSERT INTO zones VALUES (41, 223, "NJ", "New Jersey");
INSERT INTO zones VALUES (42, 223, "NM", "New Mexico");
INSERT INTO zones VALUES (43, 223, "NY", "New York");
INSERT INTO zones VALUES (44, 223, "NC", "North Carolina");
INSERT INTO zones VALUES (45, 223, "ND", "North Dakota");
INSERT INTO zones VALUES (46, 223, "MP", "Northern Mariana Islands");
INSERT INTO zones VALUES (47, 223, "OH", "Ohio");
INSERT INTO zones VALUES (48, 223, "OK", "Oklahoma");
INSERT INTO zones VALUES (49, 223, "OR", "Oregon");
INSERT INTO zones VALUES (50, 223, "PW", "Palau");
INSERT INTO zones VALUES (51, 223, "PA", "Pennsylvania");
INSERT INTO zones VALUES (52, 223, "PR", "Puerto Rico");
INSERT INTO zones VALUES (53, 223, "RI", "Rhode Island");
INSERT INTO zones VALUES (54, 223, "SC", "South Carolina");
INSERT INTO zones VALUES (55, 223, "SD", "South Dakota");
INSERT INTO zones VALUES (56, 223, "TN", "Tennessee");
INSERT INTO zones VALUES (57, 223, "TX", "Texas");
INSERT INTO zones VALUES (58, 223, "UT", "Utah");
INSERT INTO zones VALUES (59, 223, "VT", "Vermont");
INSERT INTO zones VALUES (60, 223, "VI", "Virgin Islands");
INSERT INTO zones VALUES (61, 223, "VA", "Virginia");
INSERT INTO zones VALUES (62, 223, "WA", "Washington");
INSERT INTO zones VALUES (63, 223, "WV", "West Virginia");
INSERT INTO zones VALUES (64, 223, "WI", "Wisconsin");
INSERT INTO zones VALUES (65, 223, "WY", "Wyoming");

# Canada
INSERT INTO zones VALUES (66, 38, "AB", "Alberta");
INSERT INTO zones VALUES (67, 38, "BC", "British Columbia");
INSERT INTO zones VALUES (68, 38, "MB", "Manitoba");
INSERT INTO zones VALUES (69, 38, "NF", "Newfoundland");
INSERT INTO zones VALUES (70, 38, "NB", "New Brunswick");
INSERT INTO zones VALUES (71, 38, "NS", "Nova Scotia");
INSERT INTO zones VALUES (72, 38, "NT", "Northwest Territories");
INSERT INTO zones VALUES (73, 38, "NU", "Nunavut");
INSERT INTO zones VALUES (74, 38, "ON", "Ontario");
INSERT INTO zones VALUES (75, 38, "PE", "Prince Edward Island");
INSERT INTO zones VALUES (76, 38, "QC", "Quebec");
INSERT INTO zones VALUES (77, 38, "SK", "Saskatchewan");
INSERT INTO zones VALUES (78, 38, "YT", "Yukon Territory");

# Iran
INSERT INTO zones VALUES(79, 101, "EA", "آذربایجان شرقی");
INSERT INTO zones VALUES(80, 101, "WA", "آذربایجان غربی");
INSERT INTO zones VALUES(81, 101, "AR", "اردبيل");
INSERT INTO zones VALUES(82, 101, "ES", "اصفهان");
INSERT INTO zones VALUES(83, 101, "IL", "ايلام");
INSERT INTO zones VALUES(84, 101, "BS", "بوشهر");
INSERT INTO zones VALUES(85, 101, "TH", "تهران");
INSERT INTO zones VALUES(86, 101, "CB", "چهارمحال و بختیاری");
INSERT INTO zones VALUES(87, 101, "KZ", "خوزستان");
INSERT INTO zones VALUES(88, 101, "KR", "خراسان رضوی");
INSERT INTO zones VALUES(89, 101, "KS", "خراسان شمالی");
INSERT INTO zones VALUES(90, 101, "KJ", "خراسان جنوبی");
INSERT INTO zones VALUES(91, 101, "ZN", "زنجان");
INSERT INTO zones VALUES(92, 101, "SM", "سمنان");
INSERT INTO zones VALUES(93, 101, "SB", "سيستان و بلوچستان");
INSERT INTO zones VALUES(94, 101, "FA", "فارس");
INSERT INTO zones VALUES(95, 101, "GM", "قم");
INSERT INTO zones VALUES(96, 101, "GZ", "قزوين");
INSERT INTO zones VALUES(97, 101, "KB", "كهگيلويه و بويراحمد");
INSERT INTO zones VALUES(98, 101, "KN", "كرمان");
INSERT INTO zones VALUES(99, 101, "KH", "كرمانشاه");
INSERT INTO zones VALUES(100, 101, "KD", "كردستان");
INSERT INTO zones VALUES(101, 101, "GS", "گلستان");
INSERT INTO zones VALUES(102, 101, "GL", "گيلان");
INSERT INTO zones VALUES(103, 101, "LR", "لرستان");
INSERT INTO zones VALUES(104, 101, "MA", "مازندران");
INSERT INTO zones VALUES(105, 101, "MR", "مرکزی");
INSERT INTO zones VALUES(106, 101, "HM", "همدان");
INSERT INTO zones VALUES(107, 101, "HN", "هرمزگان");
INSERT INTO zones VALUES(108, 101, "YZ", "يزد");
